@@ -536,9 +536,13 @@ ScriptCompiler *Bayonne::reload(void)
 
 	lock.enter();
 #ifdef	WIN32
-	img = new ScriptCompiler(server, "/bayonne/script");
+	img = new ScriptCompiler(server, "/bayonne/config");
 #else
-	img = new ScriptCompiler(server, "/bayonne/server/script");
+	img = new ScriptCompiler(server, "/bayonne/server/config");
+	if(provision_system)
+		img->loadPrefix("config", "/bayonne/provision/config");
+	else if(provision_user)
+		img->loadPrefix("config", "~bayonne/config");
 #endif
 
 	count = server->Keydata::getCount();
