@@ -747,46 +747,92 @@ Script::Name *BayonneSession::attachStart(Event *event)
 			goto final;
 	}
 
+	if(iface == IF_INET)
+		goto incoming;
+
 	did = getSymbol("session.dialed");
 	if(did)
 	{
-		snprintf(buf, sizeof(buf), "did.%s", did);
-		scr = (Name *)img->getPointer(buf);
-		if(scr)
-			goto final;
+		if(img->isRipple())
+		{
+			snprintf(buf, sizeof(buf), "dialed::%s", did);
+			scr = img->getScript(buf);
+			if(scr)
+				goto final;
+		}
+		else
+		{
+			snprintf(buf, sizeof(buf), "did.%s", did);
+			scr = (Name *)img->getPointer(buf);
+			if(scr)
+				goto final;
+		}
 	}
 
-	if(iface == IF_INET)
-		goto incoming;
-
 	cid = getSymbol("session.caller");
 	if(cid)
 	{
-		snprintf(buf, sizeof(buf), "cid.%s", cid);
-		scr = (Name *)img->getPointer(buf);
+		if(img->isRipple())
+		{
+			snprintf(buf, sizeof(buf), "caller::%s", cid);
+			scr = img->getScript(buf);
+			if(scr)
+				goto final;
+		}
+		else
+		{
+			snprintf(buf, sizeof(buf), "cid.%s", cid);
+			scr = (Name *)img->getPointer(buf);
+			if(scr)
+				goto final;
+		}
+	}
+
+	if(img->isRipple())
+	{
+		snprintf(buf, sizeof(buf), "slot::%d", timeslot);
+		scr = img->getScript(buf);
 		if(scr)
 			goto final;
 	}
-
-	snprintf(buf, sizeof(buf), "ts.%d", timeslot);
-	scr = (Name *)img->getPointer(buf);
-	if(scr)
-		goto final;	
+	else
+	{
+		snprintf(buf, sizeof(buf), "ts.%d", timeslot);
+		scr = (Name *)img->getPointer(buf);
+		if(scr)
+			goto final;	
+	}
 
 	if(span)
 	{
-		snprintf(buf, sizeof(buf), "span.%d", span->id);
-		scr = (Name *)img->getPointer(buf);
-		if(scr)
-			goto final;
+		if(img->isRipple())
+		{
+			snprintf(buf, sizeof(buf), "span::%d", span->id);
+			scr = img->getScript(buf);
+			if(scr)
+				goto final;
+		}
+		else
+		{
+			snprintf(buf, sizeof(buf), "span.%d", span->id);
+			scr = (Name *)img->getPointer(buf);
+			if(scr)
+				goto final;
+		}
 	}
 
-	scr = (Name *)img->getPointer("ts.default");
+	if(img->isRipple())
+		scr = img->getScript("slot::default");
+	else
+		scr = (Name *)img->getPointer("ts.default");
 	if(scr)
 		goto final;
 
 incoming:
-	scr = (Name *)img->getPointer("did.default");
+	if(img->isRipple())
+		scr = img->getScript("dialed::default");
+	else
+		scr = (Name *)img->getPointer("did.default");
 	if(scr)
 		goto final;
 
