@@ -1395,7 +1395,7 @@ attach:
 			case FORWARDED:
 				if(did && *did)
 				{
-					snprintf(buf, sizeof(buf), "forwarded:%s", did);
+					snprintf(buf, sizeof(buf), "dialed:%s", did);
 					if(digitEvent(buf))
 						break;
 				}
@@ -1407,7 +1407,7 @@ attach:
 			case PICKUP:
 				if(cid && *cid)
 				{
-					snprintf(buf, sizeof(buf), "pickup:%s", cid);
+					snprintf(buf, sizeof(buf), "caller:%s", cid);
 					if(digitEvent(buf))
 						break;
 				}
