@@ -31,6 +31,18 @@ using namespace ost;
 using namespace std;
 
 class Driver;
+class Session;
+
+#ifdef	HAVE_FOX
+
+// this is a class for the optional GUI...
+class Desktop : public Thread, public Bayonne, public ScriptBinder
+{
+public:
+	Desktop(timeslot_t ts);
+	void run(void);
+};
+#endif
 
 // this is just a quick seperate class to fetch and post keyboard input
 // to a msgport.  Maybe someday this will be a thread for a full 
@@ -58,6 +70,9 @@ public:
 	unsigned device;		// ccAudio device index
 	bool active;
 	Keyboard *keyboard;		// keyboard/console interface
+#ifdef	HAVE_FOX
+	Desktop *desktop;
+#endif
 
 	Driver();
 
