@@ -27,6 +27,8 @@ Runtime::Runtime() :
 ScriptRuntime()
 {
 	static ScriptInterp::Define interp[] = {
+		{"config", true, (Method)&ScriptMethods::scrNop,
+			(Check)&Checks::chkConfig},
 		{"key", true, (Method)&Methods::scrKey,
 			(Check)&Checks::chkKey},
 		{"dial", false, (Method)&Methods::scrDial,
